<?php
/**
 * =====================================================================================
 * File that has main html template resources for generated stylesheet and functions.php.
 *
 * @package easy-child-theme/inc/
 * =====================================================================================
 */

/**
 * =========================
 * Exit if accessed directly.
 * =========================
 */
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Loads all theme data.
$list_theme_names = '';
$parent_themes    = array();
$all_themes       = wp_get_themes();
$site_url         = get_site_url();

if ( is_array( $all_themes ) && count( $all_themes ) > 0 ) {
	foreach ( $all_themes as $textdomain => $theme ) {
		$get_themes_name      = isset( $theme['Name'] ) ? ( $theme['Name'] ) : '';
		$get_themes_templates = isset( $theme['Template'] ) ? ( $theme['Template'] ) : '';
		$get_themes_author    = isset( $theme['Author'] ) ? ( $theme['Author'] ) : '';
		$is_parent_theme      = empty( $theme->parent() ) ? true : false;

		if ( $is_parent_theme ) {
			$parent_themes[]   = $get_themes_templates;
			$list_theme_names .= '<option value="' . esc_attr( $get_themes_templates ) . ':' . esc_attr( $get_themes_name ) . '">' . esc_html( $get_themes_name ) . '</option>';
		}
	}

	$count_themes = count( $parent_themes );
	?>
	<div>
		<h1 class="grtsth-easy-child-theme-admin-title"><?php echo esc_html( 'Easy Child Theme' ); ?></h1>
		<p class="howto"><?php echo esc_html__( 'You got total ', 'grtsth_easy_child_theme' ) . esc_html( $count_themes ) . esc_html( ' themes. Select one below to generate its child theme.' ); ?></p>
	</div>
	<div>
		<form method="POST">
			<select name="grtsth_easy_child_theme_select" id="grtsth_easy_child_theme_select"><?php echo $list_theme_names; // phpcs:ignore ?></select>
			<?php wp_nonce_field( 'generate_child_theme' ); ?>
			<input type="submit" class="button button-primary button-large" name="btn_gen_child_themes" id="btn_gen_child_themes" value="Generate Child Theme" /><br/>
		</form>
	</div>
	<?php
	$selected_opt_values = isset( $_REQUEST['_wpnonce'] ) && ! empty( $_POST['grtsth_easy_child_theme_select'] ) && wp_verify_nonce( sanitize_text_field( wp_unslash( $_REQUEST['_wpnonce'] ) ), 'generate_child_theme' ) ? sanitize_text_field( wp_unslash( $_POST['grtsth_easy_child_theme_select'] ) ) : '';
	if ( ! empty( $selected_opt_values ) && array_key_exists( 'btn_gen_child_themes', $_POST ) ) { // phpcs:ignore
		$themes_root_folder        = get_theme_root();
		$split_selected_opt_values = explode( ':', $selected_opt_values );
		$selected_theme_txt_domain = $split_selected_opt_values[0];
		$selected_theme_template   = $split_selected_opt_values[0];
		$selected_theme_name       = $split_selected_opt_values[1];
		$folder_path               = $themes_root_folder . '/' . $selected_theme_txt_domain . '-child';
		$file_style_css            = $folder_path . '/style.css';
		$file_function_php         = $folder_path . '/functions.php';

		// Checks if the same folder exits inside theme directory.
		if ( file_exists( $folder_path ) ) {
			echo '<div class="notice notice-error"><p>Child of this theme already exits in WordPress <a href="' . esc_url( $site_url ) . '/wp-admin/themes.php" target="_blank">Themes</a> directory.</p></div>';
		} else {
			// Creates a folder name with suffix "-child" along selected theme's text domain.
			mkdir( $folder_path, 0777, true );

			// Data resources for stylesheet and function.php, written intentionally in unindented way.
			// phpcs:disable
			$stylesheet_data =
'/*
Theme Name:   ' . $selected_theme_name . ' Child
Description:  This is a child theme of ' . $selected_theme_name . ', generated using "Easy Child Theme" plugin by Garvit Shrestha.
Author:       ' . $get_themes_author . '
Template:     ' . $selected_theme_template . '
Version:      1.0.0
License:      GNU General Public License v2 or later
License URI:  http://www.gnu.org/licenses/gpl-2.0.html
Tags:         child-themes, easy-child-theme
Text Domain:  ' . $selected_theme_txt_domain . '-child
*/

/* You can add custom css from here */
';
			// Data resources for function.php with string replaced.
			if ( strpos( $selected_theme_template, '-' ) ) {
				$selected_theme_txt_domain_str_replace = str_ireplace( '-', '_', $selected_theme_template );
				$function_php_data =
'<?php
/**
 * Function to enqueue stylesheets of parent theme.
 */
add_action( \'wp_enqueue_scripts\', \'' . $selected_theme_txt_domain_str_replace . '_child_theme_enqueue_styles\' );
function ' . $selected_theme_txt_domain_str_replace . '_child_theme_enqueue_styles() {
	wp_enqueue_style( \'' . $selected_theme_txt_domain_str_replace . '_parent_style\', get_template_directory_uri() . \'/style.css\' );
}

// You can add your custom functions from here.
';
			} else {
				$function_php_data =
'<?php
/**
 * Function to enqueue stylesheets of parent theme.
 */
add_action( \'wp_enqueue_scripts\', \'' . $selected_theme_template . '_child_theme_enqueue_styles\' );
function ' . $selected_theme_template . '_child_theme_enqueue_styles() {
	wp_enqueue_style( \'' . $selected_theme_template . '_parent_style\', get_template_directory_uri() . \'/style.css\' );
}

// You can add your custom functions from here.
';
			}
			// File handling starts, Creates required files inside the folder created by mkdir.
			$create_style_css    = fopen( $file_style_css, 'w+' );
			$create_function_php = fopen( $file_function_php, 'w+' );
			fwrite( $create_style_css, $stylesheet_data );
			fwrite( $create_function_php, $function_php_data );
			?>
			<div class="notice notice-success">
				<p>Child theme for <strong><?php echo esc_html( $selected_theme_name ) ?></strong> has been successfully generated and activated.</p>
				<p>Like this plugin? Support us by giving <a href="<?php echo esc_url( 'https://wordpress.org/support/plugin/easy-theme-child/reviews/#new-post' ); ?>" target="_blank" title="Opens in new tab"> 5 stars</a> ratings :)</p>
			</div>
			<?php
			// phpcs:enable

		}

		// Activate the generated child theme.
		switch_theme( $selected_theme_template . '-child' );
	}
} else {
	echo '<h1><p class="howto">You don\'t have any themes in your WordPress <a href="' . esc_url( $site_url ) . '/wp-admin/themes.php" target="_blank">Themes</a> directory</p></h1>';
}
